C--------------------------------------------------------------------
C  Copyright (C) 2004,  Space Science and Engineering Center,
C  University C  of Wisconsin-Madison, Madison WI.
C
C  This program is free software; you can redistribute it
C  and/or modify it under the terms of the GNU General
C  Public License as published by the Free Software Foundation;
C  either version 2 of the License, or (at your option) any
C  later version.
C
C  This program is distributed in the hope that it will be
C  useful, but WITHOUT ANY WARRANTY; without even the implied
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public
C  License along with this program; if not, write to the Free
C  Software Foundation, Inc., 59 Temple Place, Suite 330,
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
      SUBROUTINE TOTAL_OZONE(P, O3PPMV, NL, LS, TOTAL)

C-----------------------------------------------------------------------
C !F77
C
C !DESCRIPTION:
C     Compute total column ozone given a top-down profile of
C     ozone partial pressures.
C
C !INPUT PARAMETERS:
C     P        Pressure profile (millibars)
C     O3PPMV   Ozone profile (parts per million by volume)
C     NL       Number of levels
C     LS       Surface level in profile
C
C !OUTPUT PARAMETERS:
C     TOTAL    Total column ozone (Dobsons)
C
C !REVISION HISTORY:
C
C !TEAM-UNIQUE HEADER:
C     Developed by the MODIS Group, CIMSS/SSEC, UW-Madison.
C
C !END
C-----------------------------------------------------------------------

      IMPLICIT NONE

c ... Parameters
      real oct
      parameter (oct = 0.78961)

c ... Scalar arguments
      real total
      integer ls, nl

c ... Array arguments
      real o3ppmv(nl), p(nl)

c ... Local scalars
      real phd1, phd2, tem1, tem2
      integer ip

c ... Integrate the profile
      total = 0.0
      phd1 = o3ppmv(1)
      tem1 = p(1)
      do ip = 2, ls
          phd2 = o3ppmv(ip)
          tem2 = p(ip)
          total = total + 0.5 * (phd1 + phd2) * (tem2 - tem1)
          phd1 = phd2
          tem1 = tem2
      end do
      total = total * oct

      END



