C--------------------------------------------------------------------
C  Copyright (C) 2004,  Space Science and Engineering Center,
C  University C  of Wisconsin-Madison, Madison WI.
C
C  This program is free software; you can redistribute it
C  and/or modify it under the terms of the GNU General
C  Public License as published by the Free Software Foundation;
C  either version 2 of the License, or (at your option) any
C  later version.
C
C  This program is distributed in the hope that it will be
C  useful, but WITHOUT ANY WARRANTY; without even the implied
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public
C  License along with this program; if not, write to the Free
C  Software Foundation, Inc., 59 Temple Place, Suite 330,
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
      SUBROUTINE TPRECW_NEW2(P, W, U, NL, NP, PS)

C-----------------------------------------------------------------------
C !F77
C
C !DESCRIPTION:
C     Compute total precipitable water given a top-down profile of
C     water vapor mixing ratios.
C
C !INPUT PARAMETERS:
C     P     Pressure profile (millibars)
C     W     Water vapor mixing ratio profile (grams/kilogram)
C     NL    Number of levels (assumed to be 101 levels in this version)
C     NP    Surface level in profile
C     PS  surface pressure
C
C !OUTPUT PARAMETERS:
C     U     Total precipitable water vapor (centimeters)
C
C !REVISION HISTORY:
C
C !TEAM-UNIQUE HEADER:
C     Developed by the MODIS Group, CIMSS/SSEC, UW-Madison.
C
C !END
C-----------------------------------------------------------------------

      IMPLICIT NONE

c ... Scalar arguments
      real u, ps
      integer nl, np, np2

c ... Array arguments
      real p(nl), w(nl)

c ... Local scalars
      real dp, f, p1, p2, s, w1, w2
      integer i

c ... Data statements
      data f/1961.33/

c ... Integrate the profile
c SWS changed 20 nov02: start index from 21 to 45.  for standard 101 level 
c     profile, index 45 corresponds to 103.02 hPa

      w1 = w(45)
      p1 = p(45)
      s = 0.0
      do i = 46, np
          w2 = w(i)
          p2 = p(i)
          dp = abs(p2 - p1)
          s = s + (w1 + w2) * (dp / f)
          w1 = w2
          p1 = p2
      end do

c * Add (subtract) increment of atmospheric tpw to reach surface.
c    DP will be negative if PS < P(NP)

      DP= PS-P(NP)

C SWS changed 20 nov02: compute increment using average of two 
C   levels around ps instead of only the one given
c      S = S + 2*W(NP)*DP/F

C SWS changed 12 September 2003: fixed signs here
C NOTE this requires p values be ascending (TOA to surface)

      if(p(np).gt.ps) then
          np2 = np - 1
      else if(p(np).lt.ps .and. np+1.le.nl) then
          np2 = np + 1
      else
          np2 = np
      end if  

      s = s + (w(np2)+w(np))*dp/f
      U=S 

      END
